<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="nl">
<context>
    <name>AuthFace</name>
    <message>
        <source>Face ID</source>
        <translation>Face ID</translation>
    </message>
    <message>
        <source>Verification successful</source>
        <translation>Verificatie gelukt</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation><numerusform>Verificatie mislukt - nog %n poging</numerusform><numerusform>Verificatie mislukt - nog %n pogingen</numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>Verificatie mislukt - nog 1 poging</translation>
    </message>
    <message>
        <source>Verify your Face ID</source>
        <translation>Verifieer je gezicht</translation>
    </message>
    <message>
        <source>Face ID locked, use password please</source>
        <translation>Face ID is vergrendeld - voer je wachtwoord in</translation>
    </message>
    <message>
        <source>Device unavailable!</source>
        <translation>Apparaat niet beschikbaar!</translation>
    </message>
</context>
<context>
    <name>AuthFingerprint</name>
    <message>
        <source>Verify your fingerprint</source>
        <translation>Verifieer je vingerafdruk</translation>
    </message>
    <message>
        <source>Verification successful</source>
        <translation>Verificatie gelukt</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation><numerusform>Verificatie mislukt - nog %n poging</numerusform><numerusform>Verificatie mislukt - nog %n pogingen</numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>Verificatie mislukt - nog 1 poging</translation>
    </message>
    <message>
        <source>Fingerprint locked, use password please</source>
        <translation>Vingerafdruklezer vergrendeld - voer je wachtwoord in</translation>
    </message>
</context>
<context>
    <name>AuthIris</name>
    <message>
        <source>Iris ID</source>
        <translation>Iris ID</translation>
    </message>
    <message>
        <source>Verification successful</source>
        <translation>Verificatie gelukt</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation><numerusform>Verificatie mislukt - nog %n poging</numerusform><numerusform>Verificatie mislukt - nog %n pogingen</numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>Verificatie mislukt - nog 1 poging</translation>
    </message>
    <message>
        <source>Verify your Iris ID</source>
        <translation>Verifieer je irissen</translation>
    </message>
    <message>
        <source>Iris ID locked, use password please</source>
        <translation>Iris ID is vergrendeld - voer je wachtwoord in</translation>
    </message>
</context>
<context>
    <name>AuthPasskey</name>
    <message>
        <source>Please plug in the security key</source>
        <translation>Plug de beveiligingssleutel in</translation>
    </message>
    <message>
        <source>Verification successful</source>
        <translation>Verificatie gelukt</translation>
    </message>
    <message>
        <source>Verification failed</source>
        <translation>Verificatie mislukt</translation>
    </message>
    <message>
        <source>Identifying the security key</source>
        <translation>Bezig met identificeren van sleutel…</translation>
    </message>
</context>
<context>
    <name>AuthPassword</name>
    <message>
        <source>Verification successful</source>
        <translation>Verificatie gelukt</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation><numerusform>Verificatie mislukt - nog %n poging</numerusform><numerusform>Verificatie mislukt - nog %n pogingen</numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>Verificatie mislukt - nog 1 poging</translation>
    </message>
    <message>
        <source>Wrong Password</source>
        <translation>Het wachtwoord is onjuist</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Wachtwoord</translation>
    </message>
    <message>
        <source>Please try again 1 minute later</source>
        <translation>Probeer het over 1 minuut opnieuw</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minutes later</source>
        <translation><numerusform>Probeer het over %n minuut opnieuw</numerusform><numerusform>Probeer het over %n minuten opnieuw</numerusform></translation>
    </message>
    <message>
        <source>Reset Password</source>
        <translation>Wachtwoord herstellen</translation>
    </message>
    <message>
        <source>Forgot password?</source>
        <translation>Wachtwoord vergeten?</translation>
    </message>
</context>
<context>
    <name>AuthSingle</name>
    <message>
        <source>Please try again 1 minute later</source>
        <translation>Probeer het over 1 minuut opnieuw</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minutes later</source>
        <translation><numerusform>Probeer het over %n minuut opnieuw</numerusform><numerusform>Probeer het over %n minuten opnieuw</numerusform></translation>
    </message>
    <message>
        <source>Reset Password</source>
        <translation>Wachtwoord herstellen</translation>
    </message>
    <message>
        <source>Forgot password?</source>
        <translation>Wachtwoord vergeten?</translation>
    </message>
</context>
<context>
    <name>AuthUKey</name>
    <message>
        <source>Verification successful</source>
        <translation>Verificatie gelukt</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation><numerusform>Verificatie mislukt - nog %n poging</numerusform><numerusform>Verificatie mislukt - nog %n pogingen</numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>Verificatie mislukt - nog 1 poging</translation>
    </message>
    <message>
        <source>Wrong PIN</source>
        <translation>De pincode is onjuist</translation>
    </message>
    <message>
        <source>UKey is required</source>
        <translation>UKey vereist</translation>
    </message>
    <message>
        <source>Enter your PIN</source>
        <translation>Voer je pincode in</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minute(s) later</source>
        <translation><numerusform>Probeer het over %n minuut opnieuw</numerusform><numerusform>Probeer het over %n minuten opnieuw</numerusform></translation>
    </message>
    <message>
        <source>Please try again 1 minute later</source>
        <translation>Probeer het over 1 minuut opnieuw</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minutes later</source>
        <translation><numerusform>Probeer het over %n minuut opnieuw</numerusform><numerusform>Probeer het over %n minuten opnieuw</numerusform></translation>
    </message>
</context>
<context>
    <name>AuthWidget</name>
    <message>
        <source>Account</source>
        <translation>Account</translation>
    </message>
    <message numerus="yes">
        <source>Your password will expire in %n days, please change it timely</source>
        <translation><numerusform>Je wachtwoord vervalt over %n dag - wijzig het op tijd!</numerusform><numerusform>Je wachtwoord vervalt over %n dagen - wijzig het op tijd!</numerusform></translation>
    </message>
    <message>
        <source>Password expired, please change</source>
        <translation>Je wachtwoord is verlopen - wijzig het</translation>
    </message>
    <message>
        <source>Your password has expired. Please contact the administrator to change it</source>
        <translation>Je wachtwoord is verlopen. Neem contact op met de beheerder om het te wijzigen.</translation>
    </message>
    <message>
        <source>Terminal locked, please contact administrator</source>
        <translation>De terminal is vergrendeld - neem contact op met de systeembeheerder</translation>
    </message>
</context>
<context>
    <name>DeepinAuthFramework</name>
    <message>
        <source>Wrong Password</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>GreeterWorker</name>
    <message>
        <source>Wrong account</source>
        <translation>Verkeerd account</translation>
    </message>
    <message>
        <source>Wrong Password</source>
        <translation>Het wachtwoord is onjuist</translation>
    </message>
</context>
<context>
    <name>InhibitWarnView</name>
    <message>
        <source>Cancel</source>
        <translation>Annuleren</translation>
    </message>
    <message>
        <source>The reason of inhibit.</source>
        <translation>De afsluitreden.</translation>
    </message>
</context>
<context>
    <name>LighterGreeter</name>
    <message>
        <source>Standard Mode</source>
        <translation>Standaardmodus</translation>
    </message>
</context>
<context>
    <name>LockContent</name>
    <message>
        <source>Lock Screen</source>
        <translation>Scherm vergrendelen</translation>
    </message>
    <message>
        <source>Failed to lock screen</source>
        <translation>Het scherm kan niet worden vegrendeld</translation>
    </message>
</context>
<context>
    <name>LockWorker</name>
    <message>
        <source>Fingerprint verification timed out, please enter your password manually</source>
        <translation>Vingerafdrukauthenticatie verlopen - voer je wachtwoord handmatig in</translation>
    </message>
    <message>
        <source>Failed to match fingerprint</source>
        <translation>De vingerafdruk komt niet overeen</translation>
    </message>
</context>
<context>
    <name>MultiUsersWarningView</name>
    <message>
        <source>Cancel</source>
        <translation>Annuleren</translation>
    </message>
    <message>
        <source>The above users are still logged in and data will be lost due to shutdown, are you sure you want to shut down?</source>
        <translation>Bovenstaande gebruikers zijn nog ingelogd. Niet-opgeslagen gegevens gaan verloren als gevolg van het afsluiten. Weet je zeker dat je wilt doorgaan?</translation>
    </message>
    <message>
        <source>The above users are still logged in and data will be lost due to reboot, are you sure you want to reboot?</source>
        <translation>Bovenstaande gebruikers zijn nog ingelogd. Niet-opgeslagen gegevens gaan verloren als gevolg van het opnieuw opstarten. Weet je zeker dat je wilt doorgaan?</translation>
    </message>
</context>
<context>
    <name>SessionWidget</name>
    <message>
        <source>You have enabled the high system security level, thus cannot switch to the Wayland mode, please disable the high security level in Security Center and try again.</source>
        <translation>Je kunt de Wayland-modus niet gebruiken omdat je het hoogste beveiligingsniveau hebt ingeschakeld. Schakel dit niveau uit in het beveiligingscentrum en probeer het opnieuw.</translation>
    </message>
</context>
<context>
    <name>ShutdownWidget</name>
    <message>
        <source>Shut down</source>
        <translation>Afsluiten</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Herstarten</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Pauzestand</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>Slaapstand</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>Vergrendelen</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>Afmelden</translation>
    </message>
    <message>
        <source>Switch user</source>
        <translation>Andere gebruiker</translation>
    </message>
    <message>
        <source>Switch system</source>
        <translation>Ander systeem</translation>
    </message>
    <message>
        <source>Update and Shut Down</source>
        <translation>Bijwerken en afsluiten</translation>
    </message>
    <message>
        <source>Update and Reboot</source>
        <translation>Bijwerken en herstarten</translation>
    </message>
</context>
<context>
    <name>SystemMonitor</name>
    <message>
        <source>Start system monitor</source>
        <translation>Systeemmonitor openen</translation>
    </message>
</context>
<context>
    <name>UdcpMFALoginWidget</name>
    <message>
        <source>发送验证码</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>请输入手机号</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>请输入验证码</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>获取验证码</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>UpdateWorker</name>
    <message>
        <source>Update</source>
        <translation>Bijwerken</translation>
    </message>
    <message>
        <source>Please plug in and then install updates.</source>
        <translation>Sluit de netstroomadapter aan alvorens de updates te installeren.</translation>
    </message>
</context>
<context>
    <name>UsersWithTheSameName</name>
    <message>
        <source>Return</source>
        <translation>Terug</translation>
    </message>
    <message>
        <source>Please select the account for login</source>
        <translation>Kies het account waarop je wilt inloggen</translation>
    </message>
    <message>
        <source>Local Account</source>
        <translation>Lokaal account</translation>
    </message>
    <message>
        <source>Domain Account</source>
        <translation>Domeinaccount</translation>
    </message>
</context>
<context>
    <name>WarningContent</name>
    <message>
        <source>The programs are preventing the computer from shutting down, and forcing shut down may cause data loss.</source>
        <translation>Deze programma&apos;s voorkomen dat de computer kan worden afgesloten. Doorgaan zou leiden tot gegevensverlies.</translation>
    </message>
    <message>
        <source>To close the program, click Cancel, and then close the program.</source>
        <translation>Klik op &apos;Annuleren&apos; en sluit de programma&apos;s.</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from reboot, and forcing reboot may cause data loss.</source>
        <translation>Deze programma&apos;s voorkomen dat de computer kan worden herstart. Doorgaan zou leiden tot gegevensverlies.</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from suspend, and forcing suspend may cause data loss.</source>
        <translation>Deze programma&apos;s voorkomen dat de computer kan worden onderbroken. Doorgaan zou leiden tot gegevensverlies.</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from hibernate, and forcing hibernate may cause data loss.</source>
        <translation>Deze programma&apos;s voorkomen dat de computer in de slaapstand kan worden gezet. Doorgaan zou leiden tot gegevensverlies.</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from log out, and forcing log out may cause data loss.</source>
        <translation>Deze programma&apos;s voorkomen dat je kunt afmelden. Doorgaan zou leiden tot gegevensverlies.</translation>
    </message>
    <message>
        <source>Shut down</source>
        <translation>Afsluiten</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Herstarten</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Pauzestand</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>Slaapstand</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>Afmelden</translation>
    </message>
    <message>
        <source>Are you sure you want to shut down?</source>
        <translation>Weet je zeker dat je de computer wilt uitschakelen?</translation>
    </message>
    <message>
        <source>Are you sure you want to reboot?</source>
        <translation>Weet je zeker dat je de computer opnieuw wilt opstarten?</translation>
    </message>
    <message>
        <source>Are you sure you want to log out?</source>
        <translation>Weet je zeker dat je wilt afmelden?</translation>
    </message>
    <message>
        <source>Update and Shut Down</source>
        <translation>Bijwerken en afsluiten</translation>
    </message>
    <message>
        <source>Update and Reboot</source>
        <translation>Bijwerken en herstarten</translation>
    </message>
    <message>
        <source>Closing the programs and shutting down, please wait...</source>
        <translation>Bezig met afsluiten van programma&apos;s en computer…</translation>
    </message>
    <message>
        <source>Closing the programs and rebooting, please wait...</source>
        <translation>Bezig met afsluiten van programma&apos;s en opnieuw opstarten…</translation>
    </message>
    <message>
        <source>Closing the programs and logging out, please wait...</source>
        <translation>Bezig met afsluiten van programma&apos;s en uitloggen…</translation>
    </message>
</context>
<context>
    <name>dss::module::AssistLoginWidget</name>
    <message>
        <source>Automatic login</source>
        <translation>Automatisch aanmelden</translation>
    </message>
</context>
<context>
    <name>dss::module::NetworkModule</name>
    <message>
        <source>Turn on</source>
        <translation>Inschakelen</translation>
    </message>
    <message>
        <source>Turn off</source>
        <translation>Uitschakelen</translation>
    </message>
</context>
</TS>